<?php

class YResilience_Admin extends YResilience {

	private static $instance = null;

	public static function init() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new YResilience_Admin;
		}
		return self::$instance;
	}

	public function __construct() {
		add_action( 'plugin_action_links_' . YRESILIENCE_PLUGIN_BASENAME, array( $this, 'plugin_action_links' ) );
		add_action( 'admin_menu', array( $this, 'on_admin_menu' ) );
		add_action( 'admin_post_save_yavli_settings', array( $this, 'on_save_changes' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue' ) );
	}

	public function plugin_action_links( $links ) {
		$action_links = array(
			'settings' => '<a href="' . esc_url( admin_url( 'options-general.php?page=' . YRESILIENCE_PLUGIN_ADMIN_PAGE ) ) . '" title="' . esc_attr( 'View Settings', 'yavli' ) . '">' . esc_html( 'Settings' ) . '</a>',
		);
		return array_merge( $action_links, $links );
	}

	public function admin_enqueue() {
		wp_enqueue_style( 'yavli-admin-style', YRESILIENCE_URL . '/css/yavli_admin_style.css', array(), YRESILIENCE_VERSION );
	}

	public function on_admin_menu() {
		$this->pagehook = add_submenu_page(
			'options-general.php',
			esc_html( 'Yavli Resilience' ),
			esc_html( 'Yavli Resilience' ),
			'manage_options',
			YRESILIENCE_PLUGIN_ADMIN_PAGE,
			array( $this, 'on_show_page' )
		);
		add_action( 'load-' . $this->pagehook, array( $this, 'on_load_page' ) );
	}

	public function on_load_page() {
		wp_enqueue_script( 'common' );
		wp_enqueue_script( 'wp-lists' );
		wp_enqueue_script( 'postbox' );
	}

	public function on_show_page() {
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die( esc_html( 'Access denied' ) );
		}
		$last_update_at = (int) YResilience_Options::get_option( 'last_update_at' );
		if ( $last_update_at > 0 ) {
			try {
				$dt = new DateTime( get_option( 'timezone_string' ) );
			} catch ( Exception $e ) {
				$dt = new DateTime();
			}
			$dt->setTimestamp( (int) YResilience_Options::get_option( 'last_update_at' ) );
			$last_update_at_str = date_format( $dt, 'Y-m-d H:i:s' );
			$last_update_method_str = YResilience_Options::get_option( 'last_update_method' );
		} else {
			$last_update_at_str = 'never';
			$last_update_method_str = 'none';
		}
		$last_error_msg = YResilience_Options::get_option( 'last_error_msg' );
		$enabled_checked = '';
		if ( intval( YResilience_Options::get_option( 'enabled' ) ) === 1 ) {
			$enabled_checked = ' checked';
		}
		?>
	<div id="yavli_notification_message" class="updated below-h2 dismiss hide-if-js"><p></p></div>
	<div class="wrap">
		<h2>Yavli Resilience Plugin</h2>
		<?php if ( '' !== $last_error_msg ) { ?>
			<div class="error below-h2" id=""><p>Error: <?php echo esc_html( $last_error_msg ); ?>.</p></div>
		<?php } ?>
		<div class="yavli_status_box">
			<p>Last updated at: <span><?php echo esc_html( $last_update_at_str ); ?></span></p>
			<p>Last update method: <span><?php echo esc_html( $last_update_method_str ); ?></span></p>
		</div>
		<form action="admin-post.php" method="post">
			<?php wp_nonce_field( 'yavli-credentials-nonce' ); ?>
			<input type="hidden" name="action" value="save_yavli_settings" />
			<div class="yavli_credentials">
				<p>Website ID:</p>
				<input type="text" name="website_id" value="<?php echo esc_attr( YResilience_Options::get_option( 'website_id' ) ); ?>"/>
				<p>API KEY:</p>
				<input type="text" name="api_key" value="<?php echo esc_attr( YResilience_Options::get_option( 'api_key' ) ); ?>"/>
				<p>Enabled: <input type="checkbox" name="enabled" value="1" <?php echo esc_attr( $enabled_checked ); ?>/></p>
				<p><input type="submit" value="Save And Refresh" class="button-primary" name="Submit"/></p>
			</div>
		</form>
	</div>
	<?php
	}

	private function get_current_scheme() {
		$scheme = 'http';
		if ( is_ssl() ) {
			$scheme = 'https';
		}
		return $scheme;
	}

	public function on_save_changes() {
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die( esc_html( 'Access denied' ) );
		}
		check_admin_referer( 'yavli-credentials-nonce' );

		$website_id = null;
		if ( isset( $_POST['website_id'] ) ) { // Input var okay.
			$website_id = wp_unslash( intval( $_POST['website_id'] ) ); // Input var okay.
		}
		$api_key = null;
		if ( isset( $_POST['api_key'] ) ) { // Input var okay.
			$api_key = sanitize_text_field( wp_unslash( $_POST['api_key'] ) ); // Input var okay.
		}
		$enabled = 0;
		if ( isset( $_POST['enabled'] ) && wp_unslash( intval( $_POST['enabled'] ) ) === 1 ) { // Input var okay.
			$enabled = 1;
		}

		if ( null !== $website_id && null !== $api_key ) {
			YResilience_Options::update_option( 'website_id', $website_id );
			YResilience_Options::update_option( 'api_key', $api_key );
		}
		YResilience_Options::update_option( 'enabled', $enabled );

		if ( 1 === $enabled ) {
			$this->refresh_ad_server( 'manual' );
		}

		wp_safe_redirect( esc_url_raw( admin_url( 'options-general.php?page=' . YRESILIENCE_PLUGIN_ADMIN_PAGE, $this->get_current_scheme() ) ) );
		exit();
	}
}
