<?php

class YResilience_Heartbeat extends YResilience {

	private static $instance = false;

	private $cron_schedule_name = 'yavli_resilience_interval';
	private $cron_name = 'yavli_resilience_heartbeat';

	public static function init() {
		if ( ! self::$instance ) {
			self::$instance = new YResilience_Heartbeat;
		}

		return self::$instance;
	}

	public function __construct() {
		parent::__construct();

		// Make sure our own hourly timer is present
		add_filter( 'cron_schedules' , array( $this, 'yresilience_schedule_filter' ) );
		$this->setup_cron();

		// Schedule the task
		add_action( $this->cron_name, array( $this, 'cron_exec' ) );
	}

	public function setup_cron() {
		if ( ! wp_next_scheduled( $this->cron_name ) ) {
			wp_schedule_event( time(), $this->cron_schedule_name, $this->cron_name );
		}
	}

	public function yresilience_schedule_filter( $schedules ) {
		$schedules[ $this->cron_schedule_name ] = array(
			'interval' => 3600,
			'display' => esc_html( 'Custom Interval' ),
		);
		return $schedules;
	}

	public function cron_exec() {
		// Make sure this doesn't happen more than once per hour even if called more often
		$last = (int) YResilience_Options::get_option( 'last_heartbeat' );
		if ( $last && ( $last + HOUR_IN_SECONDS - MINUTE_IN_SECONDS * 10 > time() ) ) {
			return;
		}
		YResilience_Options::update_option( 'last_heartbeat' , time() );

		if ( defined( 'DOING_CRON' ) && DOING_CRON ) {
			$update_method = 'cron';
			$this->refresh_ad_server( $update_method );
		} else {
			wp_die( esc_html( 'Access denied' ) );
		}
	}

	public function deactivate() {
		$timestamp = wp_next_scheduled( $this->cron_name );
		wp_unschedule_event( $timestamp, $this->cron_name );
	}

}
